local ipairs = ipairs
local pcall = pcall
local Prat = Prat
local Talented = Talented
local format = string.format

local L = LibStub("AceLocale-3.0"):GetLocale("Talented")

local function getChatWrite()
	local edit = DEFAULT_CHAT_FRAME.editBox
	local SendChatMessage = SendChatMessage
	local type = edit:GetAttribute("chatType")
	local lang = edit.language
	if type == "WHISPER" then
		local target = edit:GetAttribute("tellTarget")
		return function (text, ...)
			if text:find("%", 1, true) then text = text:format(...) end
			SendChatMessage(text, type, lang, target)
		end
	elseif type == "CHANNEL" then
		local channel = edit:GetAttribute("channelTarget")
		return function (text, ...)
			if text:find("%", 1, true) then text = text:format(...) end
			SendChatMessage(text, type, lang, channel)
		end
	else
		return function (text, ...)
			if text:find("%", 1, true) then text = text:format(...) end
			SendChatMessage(text, type, lang)
		end
	end
end

function Talented:ExportTemplateToChat()
	local write = getChatWrite()
	write(L["Talented - Template \"%s\" - %s :"], self.template.name, self.template.class)
	for tab, tree in ipairs(self:GetTalentInfo(self.template.class)) do
		local branchwritten = false
		for index, talent in ipairs(tree.talents) do
			local value = self.template[tab][index]
			if value > 0 then
				local ranks = talent.info.ranks
				if not branchwritten then
					write(L["%s :"], tree.info.name)
					branchwritten = true
				end
				if ranks == 1 then
					write(L["_ %s"], talent.info.name)
				else
					write(L["_ %s (%d/%d)"], talent.info.name, value, ranks)
				end
			end
		end
	end
end

function Talented:ExportTemplateURL(type)
	local write = getChatWrite()
	if type == "wowhead" then
		write(self:ExportWowheadTemplate(self.template))
	elseif type == "wowdb" then
		write(self:ExportWowdbTemplate(self.template))
	else
		write(self:ExportWowTemplate(self.template))
	end
end
